@@ -31,6 +31,7 @@ from .runners import (
     SessionWorker,
     DefaultEditor,
     ImageMagick,
+    RV,
     DefaultRunners,
 )
 from .site import (
@@ -695,6 +696,7 @@ class Project(flow.Object):
         self._RUNNERS_FACTORY.ensure_runner_type(SessionWorker)
         self._RUNNERS_FACTORY.ensure_runner_type(DefaultEditor)
         self._RUNNERS_FACTORY.ensure_runner_type(ImageMagick)
+        self._RUNNERS_FACTORY.ensure_runner_type(RV)
 
     def ensure_runners_loaded(self):
         session = self.root().session()
