@@ -12,6 +12,7 @@ from .lib import AssetDependency, DropAssetAction  # , KitsuSettingsView
 from .kitsu import KitsuSequence, KitsuShot, UpdateItemsKitsuSettings
 from .site import RequestRevisions, MultiRequestRevisions, MultiRequestedRevisions, SiteJobsPoolNames, ActiveSiteChoiceValue, ActiveSitesMultichoiceValue, RequestedRevisions
 from .dependency import get_dependencies
+from .file import GenericRunAction
 
 
 class Casting(flow.Map):
@@ -282,6 +283,131 @@ class MultiRequestShot(MultiRequestRevisions):
         return super(MultiRequestShot, self).run(button)
 
 
+class PlayblastChoiceValue(flow.values.ChoiceValue):
+    
+    CHOICES = ['Layout', 'Blocking', 'Animation', 'Compositing']
+
+    def __init__(self, parent, name):
+        super(PlayblastChoiceValue, self).__init__(parent, name)
+        self._to_update = True
+        self._exclude_choice = None
+
+    def choices(self):
+        choices = self.CHOICES.copy()
+
+        if self._exclude_choice is not None:
+            choices.remove(self._exclude_choice)
+        
+        return choices
+    
+    def exclude_choice(self, choice):
+        self._exclude_choice = choice
+        self.touch()
+    
+    def update(self, exclude_choice=None):
+        self._exclude_choice = exclude_choice
+        self._to_update = False
+
+        if self.get() == exclude_choice:
+            self.set(self.choices()[0])
+            self._to_update = True
+        
+        self.touch()
+    
+    def notify(self):
+        if self._watched and self._to_update:
+            self._mng.parent.child_value_changed(self)
+
+
+class ComparePreviews(GenericRunAction):
+
+    ICON = ('icons.libreflow', 'compare-previews')
+
+    _shot = flow.Parent()
+
+    task_1 = flow.Param('Animation', PlayblastChoiceValue).watched()
+    task_2 = flow.Param('Compositing', PlayblastChoiceValue).watched()
+
+    FILE_BY_TASK = {
+        'Layout': '/departments/layout/files/layout_movie_mov',
+        'Blocking': '/departments/animation/files/blocking_movie_mov',
+        'Animation': '/departments/animation/files/animation_movie_mov',
+        'Compositing': '/departments/compositing/files/compositing_movie_mov'
+    }
+
+    def runner_name_and_tags(self):
+        return 'RV', []
+    
+    def get_run_label(self):
+        return 'Compare previews'
+
+    def get_buttons(self):
+        self.message.set('<h2>Compare previews</h2>')
+        self.task_1.revert_to_default()
+        self.task_2.revert_to_default()
+
+        return ['Compare', 'Close']
+    
+    def get_version(self, button):
+        return super(GenericRunAction, self).get_version(button)
+    
+    def needs_dialog(self):
+        return True
+    
+    def extra_argv(self):
+        return ['-wipe'] + self._previews
+    
+    def child_value_changed(self, child_value):
+        if child_value is self.task_1:
+            self.task_2.update(exclude_choice=self.task_1.get())
+            self.task_1.exclude_choice(self.task_2.get())
+        elif child_value is self.task_2:
+            self.task_1.update(exclude_choice=self.task_2.get())
+            self.task_2.exclude_choice(self.task_1.get())
+    
+    def _get_preview_path(self, preview_oid):
+        path = None
+
+        if self.root().session().cmds.Flow.exists(preview_oid):
+            preview = self.root().get_object(preview_oid)
+            head = preview.get_head_revision()
+
+            if head is not None and head.get_sync_status() == 'Available':
+                path = head.get_path()
+        
+        return path
+    
+    def run(self, button):
+        if button == 'Close':
+            return
+        
+        preview_1_oid = self._shot.oid() + self.FILE_BY_TASK[self.task_1.get()]
+        preview_2_oid = self._shot.oid() + self.FILE_BY_TASK[self.task_2.get()]
+
+        preview_1_path = self._get_preview_path(preview_1_oid)
+
+        if preview_1_path is None:
+            self.message.set((
+                '<h2>Compare previews</h2>'
+                f'<font color=#D5000D>{self.task_1.get()} preview not available !'
+            ))
+            return self.get_result(close=False)
+        
+        preview_2_path = self._get_preview_path(preview_2_oid)
+
+        if preview_2_path is None:
+            self.message.set((
+                '<h2>Compare previews</h2>'
+                f'<font color=#D5000D>{self.task_2.get()} preview not available !'
+            ))
+            return self.get_result(close=False)
+        
+        self._previews = [preview_1_path, preview_2_path]
+        result = super(ComparePreviews, self).run(button)
+
+        return self.get_result(close=False)
+
+
 class Shot(KitsuShot):
 
     ICON = ("icons.flow", "shot")
@@ -295,6 +421,7 @@ class Shot(KitsuShot):
     
     request = flow.Child(RequestShot)
     multi_request = flow.Child(MultiRequestShot)
+    compare = flow.Child(ComparePreviews)
 
     def get_default_contextual_edits(self, context_name):
         if context_name == "settings":
@@ -563,11 +690,11 @@ class PlayblastFile(PlayblastItem):
         
         file_object = self.root().get_object(self.file_oid.get())
 
-        file_object.submit_playblast_job.revision_name.set(self.revision.get())
-        file_object.submit_playblast_job.use_simplify.set(self.use_simplify.get())
-        file_object.submit_playblast_job.priority.set(self.priority.get())
-        file_object.submit_playblast_job.pool.set(pool_name)
-        file_object.submit_playblast_job.run('Add to render pool')
+        file_object.submit_blender_playblast_job.revision_name.set(self.revision.get())
+        file_object.submit_blender_playblast_job.use_simplify.set(self.use_simplify.get())
+        file_object.submit_blender_playblast_job.priority.set(self.priority.get())
+        file_object.submit_blender_playblast_job.pool.set(pool_name)
+        file_object.submit_blender_playblast_job.run('Add to render pool')
 
 
 class PlayblastFiles(flow.DynamicMap):
@@ -813,26 +940,25 @@ class RenderSequencePlayblasts(ProcessSequenceFiles):
         oid = f'{self._sequence.oid()}/shots/{shot_name}/departments/{dept_name}/files/{file_name}'
         file = self.root().get_object(oid)
         
-        file.submit_playblast_job.revision_name.set(revision_name)
-        file.submit_playblast_job.use_simplify.set(use_simplify)
-        file.submit_playblast_job.priority.set(priority)
-        file.submit_playblast_job.pool.set(pool_name)
-        file.submit_playblast_job.run('Submit job')
+        file.submit_blender_playblast_job.revision_name.set(revision_name)
+        file.submit_blender_playblast_job.use_simplify.set(use_simplify)
+        file.submit_blender_playblast_job.priority.set(priority)
+        file.submit_blender_playblast_job.pool.set(pool_name)
+        file.submit_blender_playblast_job.run('Submit job')
     
     def submit_afterfx_playblast_job(self, shot_name, dept_name, file_name, revision_name, priority=10, pool_name='default'):
         file_name = file_name.replace('.', '_')
         oid = f'{self._sequence.oid()}/shots/{shot_name}/departments/{dept_name}/files/{file_name}'
         file = self.root().get_object(oid)
         
-        file.submit_render_images_job.revision_name.set(revision_name)
-        file.submit_render_images_job.priority.set(priority)
-        file.submit_render_images_job.pool.set(pool_name)
-        file.submit_render_images_job.run('Submit job')
+        file.submit_aftereffects_playblast_job.revision_name.set(revision_name)
+        file.submit_aftereffects_playblast_job.priority.set(priority)
+        file.submit_aftereffects_playblast_job.pool.set(pool_name)
+        file.submit_aftereffects_playblast_job.run('Submit job')
     
     def _compute_files_data(self):
         # Keep only tasks which contain Blender files
         blender_files_by_task = self.get_shot_task_files(['*.blend', '*.aep'], ['playblast'])
-        print(blender_files_by_task)
         
         shots = self._sequence.shots
         files_data = []
