@@ -191,6 +191,15 @@ class Firefox(EditFileRunner):
         return True
 
 
+class RV(EditFileRunner):
+
+    ICON = ("icons.applications", "rv")
+    TAGS = ['Video editing']
+
+    def show_terminal(self):
+        return True
+
+
 class PythonRunner(Runner):
 
     def executable(self):
