@@ -1065,10 +1065,34 @@ class WorkingSite(Site):
         return self.get_queue().jobs(type=type, status=status)
 
 
+class ClearSiteQueues(flow.Action):
+
+    ICON = ('icons.libreflow', 'clean')
+
+    _sites = flow.Parent()
+    emitted_since = flow.Param(0.0)
+
+    def get_buttons(self):
+        return ['Clear', 'Cancel']
+    
+    def run(self, button):
+        if button == 'Cancel':
+            return
+        
+        for s in self._sites.mapped_items():
+            for j in s.get_jobs(status='PROCESSED'):
+                if time.time() - j.date.get() > self.emitted_since.get():
+                    s.queue.job_list.remove(j.name())
+
+        self.root().project().synchronization.touch()
+
+
 class WorkingSites(SiteMap):
 
     ICON = ('icons.gui', 'home')
 
+    clear_site_queues = flow.Child(ClearSiteQueues)
+
     @classmethod
     def mapped_type(cls):
         return WorkingSite
